@@ -299,8 +299,7 @@ def process_absent(cloudvolume: cv.CloudVolume, process: Process) -> bool:
 
     candidates = list(filter(sameproc, logged))
 
-    if len(candidates) == 0:
-        return True
+    return len(candidates) == 0:
 
 
 def jsonify(parameters: dict) -> dict:
